summary.rdpower: Summarize RDPOWER objects

View source: R/summary.R

summary.rdpowerR Documentation

Summarize RDPOWER objects

Description

summary() prints the default robust bias-corrected output. Use all = TRUE to also display the conventional output.

Usage

## S3 method for class 'rdpower'
summary(object, ..., all = FALSE)

## S3 method for class 'rdpower'
print(x, ...)

## S3 method for class 'summary.rdpower'
print(x, ...)

## S3 method for class 'rdsampsi'
summary(object, ..., all = FALSE)

## S3 method for class 'rdsampsi'
print(x, ...)

## S3 method for class 'summary.rdsampsi'
print(x, ...)

## S3 method for class 'rdmde'
summary(object, ..., all = FALSE)

## S3 method for class 'rdmde'
print(x, ...)

## S3 method for class 'summary.rdmde'
print(x, ...)

Arguments

object

object returned by rdpower(), rdsampsi(), or rdmde().

...

additional arguments.

all

displays the conventional output in addition to the robust bias-corrected output.

x

object returned by rdpower(), rdsampsi(), or rdmde().

Value

A summary object containing the original return values, returned invisibly by the print method.


rdpower documentation built on May 18, 2026, 1:07 a.m.