| summary.rdpower | R Documentation |
summary() prints the default robust bias-corrected output. Use
all = TRUE to also display the conventional output.
## S3 method for class 'rdpower'
summary(object, ..., all = FALSE)
## S3 method for class 'rdpower'
print(x, ...)
## S3 method for class 'summary.rdpower'
print(x, ...)
## S3 method for class 'rdsampsi'
summary(object, ..., all = FALSE)
## S3 method for class 'rdsampsi'
print(x, ...)
## S3 method for class 'summary.rdsampsi'
print(x, ...)
## S3 method for class 'rdmde'
summary(object, ..., all = FALSE)
## S3 method for class 'rdmde'
print(x, ...)
## S3 method for class 'summary.rdmde'
print(x, ...)
object |
object returned by |
... |
additional arguments. |
all |
displays the conventional output in addition to the robust bias-corrected output. |
x |
object returned by |
A summary object containing the original return values, returned invisibly by the print method.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.